function pengguna = intersection(data,waktusim)
  // fungsi ini untuk mensimulasikan jumlah pengguna
  // pada tiap jalur di persimpangan untuk setiap waktu.
  // jumlah baris matriks input menyatakan jumlah jalur.
  // kolom matriks ada 9 yang menyatakan:
  // 1. Keadaan awal: inisialisasi jumlah pengguna
  // 2. Mean datang: rata-rata kedatangan pengguna
  // 3. Mean hijau: rata-rata keberangkatan saat hijau
  // 4. Mean kuning: rata-rata keberangkatan saat kuning
  // 5. Varian datang: varian kedatangan pengguna
  // 6. Varian hijau: varian keberangkatan saat hijau
  // 7. Varian kuning: varian keberangkatan saat kuning
  // 8. Max hijau: maksimum lama hijau menyala
  // 9. Max kuning: maksimum lama kuning menyala
  // selain itu, juga diinputkan waktu simulasi
  // output adalah matriks yang berisi jumlah pengguna
  // dengan baris dan kolom masing-masing menyatakan
  // jalur dan waktu

  // jumlah jalur, jumlah baris matriks data
  jmljalur = size(data,1);

  // inisialisasi
  // matriks output
  pengguna = zeros(jmljalur,waktusim);
  // jumlah pengguna
  pengguna(:,1) = data(:,1);
  // waktu simulasi
  t = 1;
  // jalur yang dilayani, indeks dikurangi satu
  jlr = 0;

  // proses simulasi
  while t < waktusim
    // menghitung lama hijau menyala
    lama = min(ceil(pengguna(jlr+1,t)/ ...
      data(jlr+1,3)),data(jlr+1,8));
    // minimum lampu lalulintas hijau menyala
    // selama 1 satuan waktu
    lama = max(min(lama,waktusim-t),1);
    // simulasi hijau menyala
    for i = 1:lama
      // membangkitkan pengguna yang datang
      pengguna(:,t+1) = max(pengguna(:,t) + ...
        data(:,2) + round(sqrt(data(:,5)).* ...
        rand(jmljalur,1,'normal')),0);
      pengguna(jlr+1,t+1) = max(pengguna( ...
        jlr+1,t+1) - data(jlr+1,3) - round( ...
        sqrt(data(jlr+1,6))*rand(1,1,'normal')),0);
      t = t + 1;
    end
    // menghitung lama kuning menyala
    lama = min(ceil(pengguna(jlr+1,t)/ ...
      data(jlr+1,4)),data(jlr+1,9));
    // minimum lampu lalulintas kuning menyala
    // selama 1 satuan waktu
    lama = max(min(lama,waktusim-t),1);
    // simulasi kuning menyala
    for i = 1:lama
      pengguna(:,t+1) = max(pengguna(:,t) + ...
        data(:,2) + round(sqrt(data(:,5)).* ...
        rand(jmljalur,1,'normal')),0);
      // menghitung pengguna yang dilayani
      pengguna(jlr+1,t+1) = max(pengguna( ...
        jlr+1,t+1) - data(jlr+1,4) - round( ...
        sqrt(data(jlr+1,7))*rand(1,1,'normal')),0);
      t = t + 1;
    end
    // mengubah jalur yang hijau atau kuning
    jlr = modulo(jlr + 1,jmljalur);
  end

  if size(pengguna,2) > waktusim
    pengguna = pengguna(:,1:waktusim);
  end
endfunction
