function pengguna = intersectionext(data,waktusim)
  // fungsi ini mensimulasikan jumlah pengguna
  // pada tiap jalur di persimpangan untuk setiap waktu.
  // jumlah baris matriks input menyatakan jumlah jalur.
  // kolom matriks ada 9 yang menyatakan:
  // 1. Keadaan awal: inisialisasi jumlah pengguna
  // 2. Mean hijau: rata-rata keberangkatan saat hijau
  // 3. Mean kuning: rata-rata keberangkatan saat kuning
  // 4. Varian hijau: varian keberangkatan saat hijau
  // 5. Varian kuning: varian keberangkatan saat kuning
  // 6. Max hijau: maksimum lama hijau menyala
  // 7. Max kuning: maksimum lama kuning menyala
  // 8. Max datang: rata-rata kedatangan pengguna
  // selain itu, juga diinputkan waktu simulasi
  // output adalah matriks yang berisi jumlah pengguna
  // baris menyatakan jalur dan kolom menyatakan waktu

  // jumlah jalur, jumlah baris matriks data
  jmljalur = size(data,1);

  // inisialisasi
  // matriks output
  pengguna = zeros(jmljalur,waktusim);
  // jumlah pengguna
  pengguna(:,1) = data(:,1);
  t = 1;
  // jalur yang dilayani, indeks dikurangi satu
  jlr = 0;

  // proses simulasi
  while t < waktusim
    // menghitung lama hijau menyala
    lama = min(ceil(pengguna(jlr+1,t)/ ...
      data(jlr+1,2)),data(jlr+1,6));
    lama = max(min(lama,waktusim-t),1);
    // simulasi hijau menyala
    for i = 1:lama
      // membangkitkan data kedatangan
      for j = 1:jmljalur
        pengguna(j,t+1) = max(pengguna(j,t) + ...
          grand(1,1,'uin',0,data(j,8)),0);
      end
      // menghitung banyak pengguna yang dilayani
      pengguna(jlr+1,t+1) = max(pengguna( ...
        jlr+1,t+1) - data(jlr+1,2) - round( ...
        sqrt(data(jlr+1,4))*rand(1,1,'normal')),0);
      t = t + 1;
    end
    // menghitung lama kuning menyala
    lama = min(ceil(pengguna(jlr+1,t)/ ...
      data(jlr+1,3)),data(jlr+1,7));
    lama = max(min(lama,waktusim-t),1);
    // simulasi kuning menyala
    for i = 1:lama
      for j = 1:jmljalur
        pengguna(j,t+1) = max(pengguna(j,t) + ...
          grand(1,1,'uin',0,data(j,8)),0);
      end
      pengguna(jlr+1,t+1) = max(pengguna( ...
        jlr+1,t+1) - data(jlr+1,3) - round( ...
        sqrt(data(jlr+1,5))*rand(1,1,'normal')),0);
      t = t + 1;
    end
    // mengubah jalur yang hijau atau kuning
    jlr = modulo(jlr + 1,jmljalur);
  end

  if size(pengguna,2) > waktusim
    pengguna = pengguna(:,1:waktusim);
  end
endfunction
