function [lam,vx,d] = maxplusmaxalgol(A)

// [lam,vx] = maxplusmaxalgol(A), Subiono algorithm to compute eigenvalue &
// eigenvector of a square matrix in max-plus algebra.
// syntax [lam,vx] = maxplusmaxalgol(A), where lam and vx are an eigenvalue and
// a corresponding eigenvector, respectively of matrix A
//
// See also 
// maxalgolpa, maxalgolepa
// 
// Max-Plus Algebra Toolbox, ver. 3.0 April, 2015
// Copyright (C) Subiono, April, 2015


az=size(A);
if az(1,1) ~= az(1, 2)
    error('The matrix does not square');
return
end

An=maxpluspwrbig(A,az(1,1))
if An==maxpluszeros(az(1,1),az(1,2))
   error('The graf G(A) does not contains a circuit')
   return
end

v=maxplusctv(A);
if max(v)~=min(v);
  error('The matrix does not has a unique eigenvalue')
return
end

lam = [];
vx = [];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

n = size(A,1);
//x = round(10*rand(n,1,"normal"));
x = zeros(n,1);

// eigenvalue
Xall = x;
x = maxplusotimes(A,x);

Xselisih = Xall - ones(1,size(Xall,2)).*.x;
q = find(max(Xselisih,'r') - min(Xselisih,'r') == 0);
while q == []
   Xall = [Xall x];
   x = maxplusotimes(A,x);
   Xselisih = Xall - ones(1,size(Xall,2)).*.x;
   q = find(max(Xselisih,'r') - min(Xselisih,'r') == 0);
end
p = size(Xall,2) + 1;
c = x(1) - Xall(1,q);
lam = c/(p - q);

// eigenvector
vx = max(ones(n,1).*.[lam*(p-q-1:-1:0)] + Xall(:,q:p-1),'c');
d=p-q;

endfunction
