function Z = minpluspwr(A,n) 

// Z = maxpluspwr(A,n), Max-plus algebraic power of matrix or scalar   
// maxpluspwr(A,n) == A^n.
// If A is a square matrix, n must be non-negative integers.
// If A is not a square matrix operation is not defined.
// If A is a square matrix, but n is not  non-negative integers  operation is not defined.
// 
// See also 
// otimes, oplus, aplus, maxplusscg, maxcircuit, maxalgol, maxalgolpa, maxalgolepa, iseigvec


// Output variables initialisation (not found in input variables)
Z = [];


mode(0);

ieee(1);
xs = size(A);
if xs(1) ~= xs(2)
   error("minpluspwr is defined only for square matrix!");
end

if xs(1)==1
  Z=n*A;
  return;
end

if isempty(A) | xs(1) > 0 & n < 0
   error("minpluspwr: empty input matrix or n < 0");
end


if xs(1) ~= xs(2)
   error("minpluspwr is defined only for square matrix!");
end

if n == 0
   Z = minpluseye(xs(1),xs(2));
   return;
end

if n == 1
   Z = A;
   return;
end

nfact = binfact(n);
Z2 = A;

//for j = 1:nfact(1);
  for j=1:nfact(1);
    Z2 = minplusotimes(Z2,Z2);
  end

Z = Z2;

for i = 2:length(nfact)
   for j = 1:nfact(i)-nfact(i-1)
      Z2 = minplusotimes(Z2,Z2);
   end
   Z = minplusotimes(Z,Z2);
end


endfunction
